/* global MapPage */

var HistoryPage = new Object();

HistoryPage.el = $('#history');
HistoryPage.page = 0;
HistoryPage.targetPage = 0;
HistoryPage.cachePages = {};

//Fonction d'initialisation, affecte les evenements.
HistoryPage.initialize = function () {
    this.eventHandler();
};

HistoryPage.eventHandler = function () {
    this.el.on('click','.leftChevron',function(){
        HistoryPage.targetPage = HistoryPage.page - 1;
        HistoryPage.getData(HistoryPage.targetPage);
    });
    
    this.el.on('click','.rightChevron',function(){
        HistoryPage.targetPage = HistoryPage.page + 1;
        HistoryPage.getData(HistoryPage.targetPage);
    });
};

HistoryPage.getData = function(page) {
    var pageData = HistoryPage.cachePages['page'+page];
    if (!!pageData)
        HistoryPage.dataReceived(pageData);
    else {
        showLoading();
        HistoryPage.requestData(page);
    }
};

HistoryPage.requestData = function(page) {
    serverRequest(
        "/history/get",
        "GET",
        function(data) {
            HistoryPage.dataReceived(data);
        },
        "get history data",
        function() {HistoryPage.requestData(page);},
        {page: page}
    );
};

HistoryPage.dataReceived = function(data) {
    HistoryPage.page = HistoryPage.targetPage;
    HistoryPage.el.find('.lines').html('');
    var ref = 'page'+HistoryPage.page;
    HistoryPage.cachePages[ref] = data;
    
    //fill the top whiteBG
    if (HistoryPage.page === 0) {
        HistoryPage.el.find('.kilometers').html(HistoryPage.computeSimpleKm(data.kilometers));
        HistoryPage.el.find('.journeys').html(data.journeys);
        HistoryPage.el.find('.driverEarnings').html(MapPage.computeSimplePrice(data.earnings));
        HistoryPage.el.find('.passengerExpenses').html(MapPage.computeSimplePrice(data.expenses));
        var pageTotal = Math.ceil(data.journeys/5);
        HistoryPage.el.find('.pageTotal').html('/'+pageTotal);
        var hoursHoover = HistoryPage.getHoursOfHooverFromMeters(data.kilometers);
        HistoryPage.el.find('.hHoover').html(hoursHoover + ' Kg');
    }
    
    //fill the lines
    var lines = data.history;
    for (var i = 0; i < lines.length; i++) {
        var line = lines[i];
        var colour;
        if (i & 1) colour = 'pink';
        else colour = 'green';
        HistoryPage.addLine(line.date, line.amount, line.nature, colour);
    }
    if (lines.length === 0) {
        HistoryPage.el.find('.lines').html('<div class="text bold center" style="margin-top: 1.2em">Aucun historique pour l\'instant</div>');
        HistoryPage.el.find('.pageControl').hide();
    } else {
        HistoryPage.el.find('.pageNumber').html(HistoryPage.page + 1);
        if (data.isNextPage === true)
            HistoryPage.el.find('.rightChevron').css('visibility', 'visible');
        else
            HistoryPage.el.find('.rightChevron').css('visibility', 'hidden');
        if (HistoryPage.page === 0)
            HistoryPage.el.find('.leftChevron').css('visibility', 'hidden');
        else
            HistoryPage.el.find('.leftChevron').css('visibility', 'visible');
    }
};

HistoryPage.addLine = function(dateReceived, amount, nature, colour) {
    var data = {};
    
    //Compute the nature of the transaction to display
    var natureS;
    if      (nature === 'ewallet')              natureS = 'e-Portemonnaie';
    else if (nature === 'cb')                   natureS = 'CB';
    else if (nature === 'cash')                 natureS = 'Cash';
    else if (nature === 'bank' & amount > 0)    natureS = 'Dépot';
    else                                        natureS = 'Retrait';
    data.nature = natureS;
    
    //check if the line needs to be grey
    if (nature === 'bank') colour = 'grey';
    data.cssClass = colour+'Bg';
    
    //Compute the spent or earned value to display
    var amountFinal;
    if (amount >= 0) amountFinal = MapPage.computeSimplePrice(amount);
    else amountFinal = MapPage.computeSimplePrice(-amount);
    if (amount > 0) data.earned = amountFinal;
    else data.spent = amountFinal;
    
    //Compute the date to display
    var date = new Date(dateReceived+" GMT");
    var year = date.getFullYear();
    var month = date.getMonth()+1;
    var day = date.getDate();
    if(day<10) day = "0"+day;
    if(month<10) month = "0"+month;
    year = year.toString().substring(2,4);
    var dateString = day+"/"+month+"/"+year;
    data.date = dateString;
    
    var line = $(history_line_template(data));
    HistoryPage.el.find('.lines').append(line);
};

//affiche la page
HistoryPage.render = function() {
    HistoryPage.reset();
    this.el.addClass("shown");
    showLoading();
    HistoryPage.requestData();
};

HistoryPage.getHoursOfHooverFromMeters = function(meters) {
    var Co2g = meters*0.14; //Average 140g/Km
    var Co2gPers = Co2g*0.5; //Average 2 pers. save 1/2
    var Co2KgPers = Co2gPers * 0.001;
    return Math.round( Co2KgPers * 10) / 10;
//    var eqCarbonneg = Co2gPers*0.2727;
//    var wH = eqCarbonneg * 11.11; //1kwh -> 0,09kg Co2Eq OR 1wh -> 0,09g
//    var HHoover = wH * 0.00138; //Average consomption of a hoover : 725 W
//    return Math.round( HHoover * 10) / 10;
};

HistoryPage.computeSimpleKm = function(km) {
    var kilo = Math.floor(km*0.001);
    var decKilo = Math.round((km-(kilo*1000))*0.01);
    if (decKilo === 10) {
        decKilo = 0;
        kilo += 1;
    }
    return kilo + ',' + decKilo + ' km';
};

HistoryPage.reset = function() {
    HistoryPage.el.find('.lines').html('');
    HistoryPage.page = 0;
    HistoryPage.cachePages = {};
    HistoryPage.el.find('.pageControl').show();
};